/*
 * Universitat Oberta de Catalunya (UOC)
 * Projecte de Final de Carrera :
 * Disseny i implementació d'un Framework de presentació
 * per aplicacions J2EE
 * 
 * Alumne : Miquel Vaquer Menorca
 */

package web.actions;

import fw.action.Action;
import fw.action.ActionForm;
import fw.config.ActionConfig;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;
import web.dades.ClientDB;
import web.model.Client;
import web.controller.Servlet;

/**
 * Classe que implementa l'Action corresponent a l'alta de Clients
 * Implementa el mètode execute, el qual obté les noves dades
 * del formulari i les afegeix a les dades de Clients (classe clientDB).
 * I el mètode validate, que valida si el client ja està donat d'alta.
 * 
 * @author Miquel Vaquer Menorca
 */
public class AltaClient implements Action 
{
    // Inicialitzar el logging amb log4j
    private static final Logger log;
    static {
        BasicConfigurator.configure();
        log = Logger.getLogger("AltaClient.class");
    }
    
    public void execute(ActionForm actionForm) throws Exception
    { 		
        log.info("execute-->"+actionForm.toString());
        ClientDB clientDB = Servlet.getInstance().getClientDB();
        List<Client> llistaClients = clientDB.getClients();
        
        // Obté les dades del nou client
        String id_Client = actionForm.getValor("id_Client");
        String nom       = actionForm.getValor("nom");
        String cognoms   = actionForm.getValor("cognoms");
        String dni       = actionForm.getValor("dni");
        String telefon   = actionForm.getValor("telefon");
        
        // Afegeix les dades del nou client a clientDB
        clientDB.addClients(id_Client,nom,cognoms,dni,telefon);
                
        // Crea una nova llista amb les dades dels clients actualitzats
        List<ActionConfig> listActionConfig = new ArrayList<ActionConfig>();
        for (Iterator<Client> it = llistaClients.iterator(); it.hasNext();){
            Client client = it.next();
            ActionConfig clientConfig = new ActionConfig();
            
            clientConfig.setValor("id_Client", client.getId_Client());
            clientConfig.setValor("nom", client.getNom());
            clientConfig.setValor("cognoms", client.getCognoms());
            clientConfig.setValor("dni", client.getDni());
            clientConfig.setValor("telefon", client.getTelefon());
            listActionConfig.add(clientConfig);
        }
        
        // A la llista creada "clients" li assigna la llista de valors
        // dels clients
        actionForm.setLlista("clients", listActionConfig);
    }
    
    /**
     * Mètode que valida el formulari de Alta d'un Client, es comprova
     * si el client ja existeix, retornant el valor booleà corresponent.
     * 
     * @param actionForm
     * @return boolean
     * @throws Exception 
     */
    public boolean validate(ActionForm actionForm) throws Exception
    {
        log.info("validate-->"+actionForm.toString());
        ClientDB clientDB = Servlet.getInstance().getClientDB();
        
        return(!clientDB.existsClient(actionForm.getValor("id_Client")));
    }
}
