/*
 * Universitat Oberta de Catalunya (UOC)
 * Projecte de Final de Carrera :
 * Disseny i implementació d'un Framework de presentació
 * per aplicacions J2EE
 * 
 * Alumne : Miquel Vaquer Menorca
 */

package web.actions;

import web.dades.ClientDB;
import web.controller.Servlet;
import web.model.Client;
import fw.action.Action;
import fw.action.ActionForm;
import fw.config.ActionConfig;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;

/**
 * Classe que implementa l'Action corresponent al Llistat de Clients.
 * Implementa el mètode execute, el qual obté de la classe clientDB
 * les dades de prova dels clients que es mostraran al llistat.
 * També implementa el mètode validate.
 * 
 * @author Miquel Vaquer Menorca
 */
public class ListClient implements Action
{    	
    // Inicialitzar el logging amb log4j
    private static final Logger log;
    static {
        BasicConfigurator.configure();
        log = Logger.getLogger("ListClient.class");
    }
    
    /**
     * Executa el formulari, obté les dades dels clients de la classe
     * clientDB i les guarda a l'actionForm
     * 
     * @param actionForm
     * @throws Exception 
     */
    public void execute(ActionForm actionForm) throws Exception
    {     
        log.info("execute-->"+actionForm.toString());
        ClientDB clientDB = Servlet.getInstance().getClientDB();
        List<Client> listClient = clientDB.getClients();
        List<ActionConfig> listActionConfig = new ArrayList<ActionConfig>();
	
        for (Iterator<Client> it = listClient.iterator(); it.hasNext();)
        {
            Client client = it.next();	
            ActionConfig clientConfig = new ActionConfig();
	
            clientConfig.setValor("id_Client", client.getId_Client());
            clientConfig.setValor("nom", client.getNom());
            clientConfig.setValor("cognoms", client.getCognoms());
            clientConfig.setValor("dni", client.getDni());
            clientConfig.setValor("telefon", client.getTelefon());
            listActionConfig.add(clientConfig);
        }
        actionForm.setLlista("clients", listActionConfig);
    }
    
    /**
     * Mètode que valida el formulari de Llista de Clients, en aquest cas
     * no valida res, dirèctament retorna true.
     * 
     * @param actionForm
     * @return
     * @throws Exception 
     */
    public boolean validate(ActionForm actionForm) throws Exception
    {
        log.info("validate-->"+actionForm.toString());
        return true;
    }
}
