/*
 * Universitat Oberta de Catalunya (UOC)
 * Projecte de Final de Carrera :
 * Disseny i implementació d'un Framework de presentació
 * per aplicacions J2EE
 * 
 * Alumne : Miquel Vaquer Menorca
 */

package web.controller;

import fw.exceptions.TomirException;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;
import web.dades.ClientDB;

/**
 * Classe que defineix el Servlet de l'aplicació
 * @author Miquel Vaquer Menorca
 */
public class Servlet
{
    // Inicialitzar el logging amb log4j
    private static final Logger log;
    static {
        BasicConfigurator.configure();
        log = Logger.getLogger("Servlet.class");
    }
    
    private ClientDB clientDB;
    private static Servlet servlet;
    
    private Servlet() throws Exception{
    }
    
    /**
     * Crea un nou servlet si no està creat.
     * Implementa patró Singleton.
     *
     * @return servlet
     */
    public static Servlet getInstance()
    {
        log.info("getInstance-->instanciar Servlet");
        if (servlet == null)
        {
            try 
            {
                servlet = new Servlet();
            }
            catch (Exception e)
            {
                log.error("getInstance-->Error creant el Servlet "+e.getMessage());
                throw new TomirException("ERROR creant el Servlet");
            }
        }
        return servlet;
    }
    
    /**
     * Crea una nova instància de ClientDB, la qual conté les dades
     * dels clients de prova per a l'aplicació web.
     * Implementa patró Singleton.
     *
     * @return
     * @throws Exception
     */
    public ClientDB getClientDB () throws Exception
    {
        log.info("getClientDB-->Crear classe que conté les dades dels clients");
        if (clientDB == null)
        {
            try
            {
                clientDB = new ClientDB();
            }
            catch(Exception e)
            {
                log.error("getClientDB-->Error creant la classe ClientDB "+e.getMessage());
                throw new TomirException("ERROR creant la classe ClientDB");
            }
        }
        return clientDB;
    }
}
