/*
 * Universitat Oberta de Catalunya (UOC)
 * Projecte de Final de Carrera :
 * Disseny i implementació d'un Framework de presentació
 * per aplicacions J2EE
 * 
 * Alumne : Miquel Vaquer Menorca
 */

package web.dades;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;
import web.model.Client;

/**
 * Classe que conté les dades que es mostraran al formulari (Clients)
 * @author Miquel Vaquer Menorca
 */
public class ClientDB
{
    // Inicialitzar el logging amb log4j
    private static final Logger log;
    static {
        BasicConfigurator.configure();
        log = Logger.getLogger("ClientDB.class");
    }
    
    private List<Client> llistaClients;
    
    /**
     * Constructor: Crear nou array de clients amb els valors de prova dels clients
     */
    public ClientDB() 
    {
        super();
        if(llistaClients == null) 
        {
            llistaClients = new ArrayList<Client>();
            llistaClients.add(new Client("01","Miquel","Vaquer Menorca","43.082.672-S","634342324"));
            llistaClients.add(new Client("02","Joan","Rotger Gelabert","43.565.987-P","654332272"));
            llistaClients.add(new Client("03","Albert","Rocamora Florit","41.234.762-V","622896534"));
            llistaClients.add(new Client("04","Josep","Pujol Roca","43.212.957-M","616894521"));
            llistaClients.add(new Client("05","Silvia","Pujades Lorca","43.999.888-Z","667432782"));
        }    
        log.info("Contructor-->Omplir la llista de clients amb valors de prova "+llistaClients.toString());
    }
    
    /**
     * Retorna la llista de Clients.
     * 
     * @return List<Client>
     */
    public List<Client> getClients()
    {
        return llistaClients;
    }
    
    /**
     * Afegir un nou client a la llista de Clients.
     * 
     * @param id_Client
     * @param nom
     * @param cognoms
     * @param dni
     * @param telefon
     * @return 
     */
    public Boolean addClients (String id_Client, String nom, String cognoms,
            String dni, String telefon)
    {
        String idClient      = id_Client;
        String nomClient     = nom;
        String cognomsClient = cognoms;
        String dniClient     = dni;
        String telefonClient = telefon;
        
        try
        {
            Client client = new Client(idClient, nomClient, cognomsClient, dniClient, telefonClient);
            llistaClients.add(client);
            log.info("addClients-->Afegir client "+id_Client+" a la llista de Clients");
            return true;
        }
        
        catch (Exception e) 
        {
            log.error("addClients-->Error afegint client "+id_Client);
            return false;
        }
    }
    
    /**
     * Comprova si un determinat codi de client ja existeix a la llista de Clients.
     * 
     * @param id_Client
     * @return boolean
     */
    public Boolean existsClient (String id_Client)
    {
        boolean trobat=false;
        Iterator iterator = llistaClients.iterator();
        Client client;
        
        log.info("existsClient-->Comprovar si el client "+id_Client+" ja existeix");
        while((iterator.hasNext()) && (!trobat))
        {
            client=(Client)iterator.next();
            trobat=id_Client.equalsIgnoreCase(client.getId_Client());
        }
        
        return (trobat);
    }
}