/*
 * Universitat Oberta de Catalunya (UOC)
 * Projecte de Final de Carrera :
 * Disseny i implementació d'un Framework de presentació
 * per aplicacions J2EE
 * 
 * Alumne : Miquel Vaquer Menorca
 */

package fw.action;

import fw.config.ActionConfig;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.Set;
import java.util.List;
import javax.servlet.ServletRequest;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;

/**
 * Mètode que gestiona els formularis
 * 
 * @author Miquel Vaquer Menorca
 */
public class ActionForm extends ActionConfig 
{
    // Inicialitzar el logging amb log4j
    private static final Logger log;
    static {
        BasicConfigurator.configure();
        log = Logger.getLogger("ActionForm.class");
    }
    
    // Variable que guarda el pròxim jsp a mostrar
    private List<String> JspMap;

    /**
     * Constructor, crea l'array de Jsp i crida al mètode
     * abstracte (implementat a la web client) que afegirà
     * un formulari Jsp a l'array.
     */
    public ActionForm() {
        super();
        JspMap = new ArrayList<String>();
    }

    /**
     * Mètode que recull els valors del formularis (request) i
     * són assignats als objectes 
     * 
     * @param servletRequest 
     */
    public void map(ServletRequest servletRequest) 
    {
        Set<String> llistaCamps = super.getFields();
        Iterator<String> campsIterator = llistaCamps.iterator();
        while (campsIterator.hasNext()) 
        {
            String camp = campsIterator.next();
            String valor = servletRequest.getParameter(camp);
            if (valor != null) super.setValor(camp, valor);   
            log.info("map-->setValor("+camp+","+valor);
        }
    }

    /**
     * Mètode que afegeix una pàgina jsp al map de jsp's
     * Per exemple: jsp= "clientsList"
     * 
     * @param jsp 
     */
    protected void addJsp(String jsp) 
    {
        log.info("addJsp-->jsp= "+jsp);
        JspMap.add(jsp);
    }

    /**
     * Retorna el jsp de la llista de jsp
     * 
     * @return jsp
     * @throws IOException 
     */
    public String getJsp() throws IOException 
    {
        String jsp = null;
        int i = 0;
        while (jsp == null & i < JspMap.size()) 
        {
            jsp = JspMap.get(i);
            log.info("getJsp-->jsp= "+jsp);
            i++;
        }
        return jsp;
    }
    
}
