/*
 * Universitat Oberta de Catalunya (UOC)
 * Projecte de Final de Carrera :
 * Disseny i implementació d'un Framework de presentació
 * per aplicacions J2EE
 * 
 * Alumne : Miquel Vaquer Menorca
 */
package fw.config;

import fw.exceptions.TomirException;
import java.io.File;
import java.net.URL;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Set; 
import java.util.List;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

/**
 * Classe pare per a la configuració dels formularis
 * 
 * @author Miquel Vaquer Menorca
 */
public class ActionConfig 
{
    // Inicialitzar el logging amb log4j
    private static final Logger log;
    static {
        BasicConfigurator.configure();
        log = Logger.getLogger("ActionConfig.class");
    }
    
    // Map amb la llista de camps (Per exemple : id_Client, String)
    private HashMap<String, FieldConfig> fields;  
    
    // Map amb la llista de valors dels valors dels camps
    private HashMap<String, List<ActionConfig>> llistes; 
    
    // Variable per configurar les dades dels camps
    private FieldConfig fieldConfig; 

    /**
     * Contructor: Inicialitza els map i parsea de la configuració
     * els camps i els seus tipus.
     */
    public ActionConfig() 
    {
        fields      = new HashMap<String, FieldConfig>();
        llistes     = new HashMap<String, List<ActionConfig>>();
        fieldConfig = null;
        parserFields();
    }

    /**
     * Mètode que afegeix un camp al map de camps (Nom i Tipus del camp)
     * Per exemple : nom=id_Client, tipus=String
     * @param nom
     * @param tipus 
     */
    protected void setFields(String nom, String tipus) 
    {
        log.info("afegirCamp-->nom= "+nom+" tipus= "+tipus);
        
        // Crear un nou camp, assignant-li el tipus
        fieldConfig = new FieldConfig(tipus);
        
        // Afegir el camp al map de camps
        fields.put(nom, fieldConfig);
    }
    
    /**
    * Retorna els valors (keys) del map de camps (fields)
    * 
    * @return fields.keySet()
    */
    public Set<String> getFields() 
    {
        log.info("getFields-->fields.keys= "+fields.keySet().toString());
        return fields.keySet();
    }

    /**
     * Afegeix noves entrades als maps de Llista de valors.
     * Per exemple: "clients", List<ActionConfig> afegirà a una llista
     * anomenada "Clients" amb els valors dels camps
     * 
     * @param nom_llista
     */
    protected void addList(String nom_llista) 
    {
        log.info("addList-->nom_llista= "+nom_llista);
        try 
        {
            List<ActionConfig> listActionConfig = new ArrayList<ActionConfig>();
            llistes.put(nom_llista, listActionConfig);
            log.info("addList-->llistes.put("+nom_llista+","+listActionConfig.toString()+")");
        }
        catch (Exception e) 
        {
            log.error("addList-->Error afegint la llista de valors"+e.getMessage());
            e.getMessage();
        }
    }

    /**
     * Mètode que assigna el nom i valor a un camp.
     * Per exemple: nom_field="id_Client" , valor_field="01"
     * 
     * @param nom_field
     * @param valor_field 
     */
    public void setValor(String nom_field, String valor_field) 
    {
        if (fields.containsKey(nom_field)) 
        {
            fieldConfig = fields.get(nom_field);
            log.info("setValor-->nom_field= "+nom_field+" valor_field= "+valor_field);
                        
            try 
            {
                fieldConfig.setValor(valor_field);
            } 
            catch (Exception e) {
                e.getMessage();
                log.error("setValor: "+e.getMessage());
            }
        }
        else{
            log.error("setValor-->El nom del camp no és correcte ");
            throw new TomirException("El nom del camp no és correcte");
        }
    }

    /**
     * Mètode que recupera el valor de un field (camp)
     * 
     * @param nom_field
     * @return fields.get(nom_field)
     */
    public String getValor(String nom_field) 
    {
        if (fields.containsKey(nom_field)) 
        {
            if (fields.get(nom_field) == null) 
                throw new TomirException("El nom del camp està en blanc");
            else
            {
                log.info("getValor-->fields.get("+nom_field+")= "
                        +fields.get(nom_field).toString());
                return fields.get(nom_field).toString();
            }
        } 
        else {
            log.error("getValor-->El nom del camp no és correcte");
            throw new TomirException("El nom del camp no és correcte");
        }
    }


    /**
     * Mètode que assigna una llista de valors () al hashmap
     * 
     * @param nom
     * @param listActionConfig 
     */
    public void setLlista(String nom, List<ActionConfig> listActionConfig) 
    {
        if (!listActionConfig.isEmpty())
        {
            if (llistes.containsKey(nom)) 
            {    
                log.info("setLlista-->nom= "+nom+" valors= "+listActionConfig.toString());
                try{
                    llistes.put(nom, listActionConfig);   
                }
                catch (Exception e){
                    log.error("setLlista-->Error assignant la llista de valors "+e.getMessage());
                    throw new TomirException("Error assignant la llista de valors");
                }
            }
        }
    }

    /**
     * Retorna la llista (hashmap) amb els valors d'una llista
     * @param nom
     * @return List<ActionConfig>
     */
    public List<ActionConfig> getLlista(String nom) 
    {
        if (llistes.containsKey(nom)) 
        {
            log.info("getLlista-->llistes.get("+nom+")= "+llistes.get(nom));
            return llistes.get(nom);

        } else {
            log.error("getLlista-->No es pot recuperar la llista de valors");
            throw new TomirException("No es pot recuperar la llista de valors");
        }
    }
   
   /**
    * Mètode que parsea els valors dels camps (nom i tipus) del fitxer 
    * de configuració del framework (tomir-config.xml).
    * Utilitza el parser DOM.
    */
   private void parserFields()
   {
       try {
           log.info("Inici parserFields");
           URL xml = this.getClass().getResource("/tomir-config.xml");
           File tomir = new File(xml.getPath());
           DocumentBuilderFactory dbFactory = DocumentBuilderFactory.newInstance();
           DocumentBuilder dBuilder = dbFactory.newDocumentBuilder();
           Document doc = dBuilder.parse(tomir);
           doc.getDocumentElement().normalize();
           NodeList nodes;
           
           nodes = doc.getElementsByTagName("camp");
           for (int i = 0; i < nodes.getLength(); i++) {
               Node node = nodes.item(i);
               
               if (node.getNodeType() == Node.ELEMENT_NODE) {
                   Element element = (Element) node;
                   setFields(getValue("nom", element), getValue("tipus", element));
               }
           }
       }
       
       catch (Exception ex) 
       {
           log.error("parserFields-->Error de parseig del fitxer tomir-config.xml "+ex.getMessage());
           throw new TomirException("Error parsejant el fitxer tomir-config.xml");
       }
   }
   
   private static String getValue(String tag, Element element) {
       NodeList nodes = element.getElementsByTagName(tag).item(0).getChildNodes();
       Node node = (Node) nodes.item(0);
       return node.getNodeValue();
   }
   
}