/*
 * Universitat Oberta de Catalunya (UOC)
 * Projecte de Final de Carrera :
 * Disseny i implementació d'un Framework de presentació
 * per aplicacions J2EE
 * 
 * Alumne : Miquel Vaquer Menorca
 */

package fw.config;

import fw.exceptions.TomirException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;

/**
 * Classe que gestiona els valors dels camps del formulari
 * mirant de quin tipus és i el converteix al tipus corresponent
 * 
 * @author Miquel Vaquer Menorca
 */
public class FieldConfig 
{
    private Comparable camp;
    private String tipus;
    
    // Inicialitzar el logging amb log4j
    private static final Logger log;
    static {
        BasicConfigurator.configure();
        log = Logger.getLogger("FieldConfig.class");
    }
    
    /**
     * Constructor
     */
    public FieldConfig() {
        super();
        camp = null;
        tipus = "";
    }
    
    /**
     * Constructor 
     * 
     * @param tipus 
     */
    public FieldConfig(String tipus) {
        super();
        this.camp = null;
        this.tipus = tipus;
    }
    
    /**
     * Mètode que reb el valor i l'instancia al tipus corresponent
     * (String, Integer, Float, Long, ...)
     * 
     * @param valor
     * @throws Excep 
     */
    public void setValor(String valor) throws ParseException
    {
        try 
        {
            if (tipus.equalsIgnoreCase("String")){
                camp = valor;
            }
            if (tipus.equalsIgnoreCase("Integer")){
                camp = new Integer(valor);
            }
            if (tipus.equalsIgnoreCase("Float")){
                camp = new Float(valor);
            }
            if (tipus.equalsIgnoreCase("Long")){
                camp = new Long(valor);
            }
            if (tipus.equalsIgnoreCase("Double")){
                camp = new Double(valor);
            }
            if (tipus.equalsIgnoreCase("Date"))
            {
                 SimpleDateFormat formato = new SimpleDateFormat("dd/MM/yyyy");
                 String strFecha = valor;
                 Date fechaDate = null;
                 fechaDate = formato.parse(strFecha);
                 camp = fechaDate;
            }
            if (tipus.equalsIgnoreCase("Boolean"))
            {
                camp = Boolean.valueOf(valor);
            }
         log.info("setValor-->camp= "+valor);   
        }
        catch (ParseException e){
            log.error("setValor-->Error de tipus de dades "+e.getMessage());
            throw new TomirException("Error de tipus de dades "+e.getMessage());
        }
    }
    
    /**
     * Mètode toString(), formateja el valor a tipus String
     * 
     * @return valor
     */
    @Override
    public String toString()
    {
        String valor = null;
        
        if (camp!=null)
        {
            if (tipus.equalsIgnoreCase("String")){
                valor = (String)camp;
            }
            if (tipus.equalsIgnoreCase("Integer")){
                valor = ((Integer)camp).toString();
            }
            if (tipus.equalsIgnoreCase("Float")){
                valor = ((Float)camp).toString();
            }
            if (tipus.equalsIgnoreCase("Long")){
                valor = ((Long)camp).toString();
            }
            if (tipus.equalsIgnoreCase("Double")){
                valor = ((Double)camp).toString();
            }
            if (tipus.equalsIgnoreCase("Date"))
            {
                SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy");
                valor = sdf.format(camp);
            }
            if (tipus.equalsIgnoreCase("Boolean")){
                valor = ((Boolean)camp).toString();
            }
        }
        else
            throw new TomirException("Tipus de dades incorrecte");
        
        return valor;
    }
    
    /**
     * Inicialitza el camp
     */
    public void clear(){
        camp = null;
    }
    
}
