/*
 * Universitat Oberta de Catalunya (UOC)
 * Projecte de Final de Carrera :
 * Disseny i implementació d'un Framework de presentació
 * per aplicacions J2EE
 *
 * Alumne : Miquel Vaquer Menorca
 */

package fw.controller;

import fw.config.Configuracio;
import java.io.IOException;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import fw.action.ActionForm;
import fw.action.Action;
import fw.exceptions.TomirException;
import fw.i18n.ResourceBundleConfig;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;

/**
 * Classe que processa la petició desde el Servlet
 *
 * @author Miquel Vaquer Menorca
 */
public class ApplicationController
{
    // Inicialitzar el logging amb log4j
    private static final Logger log;
    static {
        BasicConfigurator.configure();
        log = Logger.getLogger("ApplicationController.class");
    }
    
    // Obtenir la configuració carregada desde tomir-config.xml
    Configuracio configuracio = Configuracio.getConfiguracio();
    
    // Obtenir la internacionalitzacio carregada desde tomir-config.xml
    ResourceBundleConfig resourceBundleConfig = ResourceBundleConfig.getResourceBundleConfig();
    
    /**
     * Mètode que processa la petició i retorna la pròxima vista a mostrar.
     *
     * @param request
     * @param response
     * @return nextPage
     * @throws ServletException
     * @throws IOException
     */
    protected String processRequest(ServletRequest request, ServletResponse response)
            throws ServletException, IOException
    {
        String jsp;
        String nextPage;
        
        // Parsear valors de la configuració del Framework
        configuracio.parserTOMIR();
        
        // Parsear valors de internacionalització (i18n) del Framework
        resourceBundleConfig.parserResourceBundle();
        
        // Recull del request el nom de l'acció (action)
        String nameAction = request.getParameter("action");
        log.info("processRequest-->nameAction= " + nameAction);
        
        // Obté l'ActionForm (formulari) de la configuració
        ActionForm actionForm = configuracio.getActionForm(nameAction);
        log.info("processRequest-->actionForm= " + actionForm.toString());
        
        // Recull les dades del client del formulari i les assigna a l'objecte
        actionForm.map(request);
        
        // Obté l'objecte Action instanciat a la configuració
        Action action = configuracio.getAction(nameAction);
        log.info("processRequest-->action= "+action.toString());
        
        try 
        {
            // Executa l'ActionForm si la validació del formulari és correcte
            if(action.validate(actionForm))
            {
                log.info("processRequest-->Executar ActionForm : "+actionForm.toString());
                action.execute(actionForm);
                
                // Obté la següent pàgina (jsp) a mostrar
                jsp = actionForm.getJsp();
                log.info("processRequest-->pageNext= " + jsp);
            }
            else
            {
                log.error("ProcessRequest-->Formulari: "+actionForm.toString()+" no validat");
                
                // S'assigna com a pròxima pàgina a visualitzar, errorTomir (errors)
                jsp="errorTomir";
            }
            
            if (jsp == null)
                throw new TomirException("ERROR - Pàgina següent a mostrar és NULL");
            
            // Guardar al request la variable JspForm amb el formulari (actionForm)
            request.setAttribute("JspForm", actionForm);
            
            // Variable que conté la pròxima pàgina jsp a mostrar.
            nextPage = "/" + jsp + ".jsp";
        }
        catch(TomirException e) {
            log.error("processRequest-->Pàgina següent a mostrar és NULL--> "+e.getMessage());
            nextPage="/errorTomir.jsp";
        }
        catch (Exception e) {
            log.error("processRequest-->ERROR D'EXECUCIO :" + e.getMessage());
            nextPage="/errorTomir.jsp";
        }
        return nextPage;
    }
}
