/*
 * Universitat Oberta de Catalunya (UOC)
 * Projecte de Final de Carrera :
 * Disseny i implementació d'un Framework de presentació
 * per aplicacions J2EE
 * 
 * Alumne : Miquel Vaquer Menorca
 */

package fw.controller;

import java.io.IOException;
import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;

/**
 * Front Controller, hereda de la classe Servlet del sistema, desde la configuració del 
 * descriptor de desplegament (web.xml) captura totes les peticions url que codifiquen 
 * el nom del action a executar
 * 
 * @author Miquel Vaquer Menorca 
 * 
 */
public class FrontController extends HttpServlet 
{
    // Inicialitzar el logging amb log4j
    private static final Logger log;
    static {
        BasicConfigurator.configure();
        log = Logger.getLogger("FrontController.class");
    }
    
    /**
     * Inicialitza el Servlet
     * @throws ServletException 
     */
    @Override
    public void init() throws ServletException {
       
    }

    /**
     * Destrueix el Servlet
     */
    @Override
    public void destroy() {
    }
    
    /**
     * Constructor
     */
    public FrontController() {
        super();
    }

    /**
     * El mètode doGet és invocat si el formulari passa els valors per el mètode Get.
     * En aquest cas el processament és el mateix per get i post
     * @param request
     * @param response
     * @throws ServletException
     * @throws IOException 
     */
    @Override
    protected void doGet(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException
    {
        doPost(request, response);
    }

    /**
     * Es delega la petició a la classe ApplicationController, la qual retorna la
     * següent pàgina a executar
     * @param request
     * @param response
     * @throws ServletException
     * @throws IOException
     */
    @Override
    protected void doPost(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        String nextPage = null;
        try
        {
            log.info("FrontController-->doPost");
            String Page = (new ApplicationController()).processRequest(request, response);
            log.info("FrontController-->nextPage "+Page);
            nextPage = Page;
        } catch (Throwable t) {
            t.getMessage();
        }
        RequestDispatcher rd = getServletContext().getRequestDispatcher(response.encodeURL(nextPage));
        rd.forward(request, response);
    }
}
