/*
 * Universitat Oberta de Catalunya (UOC)
 * Projecte de Final de Carrera :
 * Disseny i implementació d'un Framework de presentació
 * per aplicacions J2EE
 *
 * Alumne : Miquel Vaquer Menorca
 */
package fw.i18n;

import fw.exceptions.TomirException;
import java.io.File;
import java.net.URL;
import java.util.Locale;
import java.util.ResourceBundle;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

/**
 * Classe utilitzada per a llegir properties en diferents idiomes
 * @author Miquel Vaquer Menorca
 *
 */
public class ResourceBundleConfig
{
    // Inicialitzar el logging amb log4j
    private static final Logger log;
    static {
        BasicConfigurator.configure();
        log = Logger.getLogger("ResourceBundleConfig.class");
    }
    
    // Configuració de la internacionalització (i18N)
    private ResourceBundle resourceBundle;
    
    // Instanciar la classe. Es defineix private ja que només
    // s'accedirà desde aquesta classe (patró SINGLETON)
    private static ResourceBundleConfig resourceBundleConfig;
    
    private ResourceBundleConfig(){
        
    }
    
    /**
     * Mètode que retorna l'objecte ResourceBundleConfig, si no existeix
     * es crea un objecte nou. (Patró SINGLETON)
     * @return ResourceBundleConfig
     */
    public static ResourceBundleConfig getResourceBundleConfig()
    {
        if (resourceBundleConfig == null) resourceBundleConfig = new ResourceBundleConfig();
        return resourceBundleConfig;
    }
    
    /**
     * Mètode que retorna la classe ResourceBundle configurada amb la
     * internacionalitzacio definida en el fitxer tomir-config.xml
     * 
     * @return ResourceBundle
     */
    public ResourceBundle getBundleTomir()
    {
        return resourceBundle;
    }
    
    /**
     * Mètode que parsea els valors de Internacionalitzacio (i18n)
     * Utilitzant DOM, llegeix el fitxer de configuració (tomir-config.xml)
     */
    public void parserResourceBundle()
    {
        try {
            
            log.info("Inici parserResourceBundle");
            URL xml = this.getClass().getResource("/tomir-config.xml");
            File tomir = new File(xml.getPath());
            DocumentBuilderFactory dbFactory = DocumentBuilderFactory.newInstance();
            DocumentBuilder dBuilder = dbFactory.newDocumentBuilder();
            Document doc = dBuilder.parse(tomir);
            doc.getDocumentElement().normalize();
            NodeList nodes;
            
            nodes = doc.getElementsByTagName("i18n");
            for (int i = 0; i < nodes.getLength(); i++) 
            {
                Node node = nodes.item(i);
                if (node.getNodeType() == Node.ELEMENT_NODE)
                {
                    Element element = (Element) node;
                    Locale.setDefault(new Locale(getValue("idioma", element), getValue("pais", element)));
                    resourceBundle = ResourceBundle.getBundle(getValue("path", element), Locale.getDefault());
                    log.info("parserResourceBundle-->Configurar i18n ");
                }
            }
        }
        catch (Exception e) 
        {
            log.error("ParserResourceBundle-->Error en el parseig");
            throw new TomirException("Error en el parseig"+e.getMessage());
        }
    }
    
    private static String getValue(String tag, Element element) {
        NodeList nodes = element.getElementsByTagName(tag).item(0).getChildNodes();
        Node node = (Node) nodes.item(0);
        return node.getNodeValue();
    }
}
