/*
 * Universitat Oberta de Catalunya (UOC)
 * Projecte de Final de Carrera :
 * Disseny i implementació d'un Framework de presentació
 * per aplicacions J2EE
 * 
 * Alumne : Miquel Vaquer Menorca
 */

package fw.tags;

import fw.action.ActionForm;
import javax.servlet.jsp.tagext.TagSupport;
import javax.servlet.jsp.JspWriter;
import javax.servlet.ServletRequest;

import java.util.Iterator;
import java.util.List;
import java.util.ArrayList;
import java.util.StringTokenizer;

import fw.config.ActionConfig;
import fw.i18n.ResourceBundleConfig;
import java.util.ResourceBundle;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;

/**
 * Classe que gestiona les etiquetes de la pàgina clientsList.jsp,
 * per visualitzar la taula de clients
 * 
 * @author Miquel Vaquer Menorca
 */
public class TableListTag extends TagSupport
{
    // Inicialitzar el logging amb log4j
    private static final Logger log;
    static {
        BasicConfigurator.configure();
        log = Logger.getLogger("TableListTag.class");
    }
    
    private String nomLlista;
    private List<String> capçalera;
    private List<String> camps;
   
    // Obtenir la configuració carregada desde tomir-config.xml
    ResourceBundleConfig resourceBundleConfig = ResourceBundleConfig.getResourceBundleConfig();
    
    // Obtenir el ResourceBundle (i18n) de la configuració
    ResourceBundle bundle = resourceBundleConfig.getBundleTomir();
    
    @Override
    public int doStartTag() 
    {
        if (camps==null){camps=new ArrayList<String>();}
        ServletRequest request = pageContext.getRequest();
        ActionForm actionForm = (ActionForm)request.getAttribute("JspForm");
        
        if (actionForm != null) 
        {
            List<ActionConfig> llista = actionForm.getLlista(nomLlista); 
            if (llista != null) 
            {
                try {
                    JspWriter writter = pageContext.getOut();
                    
                    // ------ Capçalera Taula Clients ------
                    writter.write("<tr>");
                    for (Iterator<String> it = capçalera.iterator(); it.hasNext();)
                    {
                        String columna = it.next();
                        writter.write("<th>"+bundle.getString(columna)+"</th>");
                    }
                    int numCamps = camps.size();
                    writter.write("</tr>");
                    
                    if (llista.isEmpty()){
                        writter.write("<TR><TD colspan=\""+numCamps+"\" align=\"center\">No hi ha cap registre</TD></TR>");
                    } else {
                        for (Iterator<ActionConfig> it=llista.iterator(); it.hasNext();){
                            writter.write("<tr>");
                            ActionConfig cl = it.next();
                            for (Iterator<String> itc = camps.iterator(); itc.hasNext();){
                                String v = cl.getValor(itc.next());
                                writter.write("<td>"+v+"</td>");
                            }
                            writter.write("</tr>");
                        }
                    }
                } 
                catch(Exception e) {
                    log.error("Error construint TableListTag "+e.getMessage());
                }
                return(EVAL_BODY_INCLUDE);
            } 
            else 
            {
                log.error("Error construint TableListTag Llista "+nomLlista+" no existeix a request");
                return(SKIP_BODY);
            }
        } 
        else 
        {
            log.error("Error construint TableListTag JspForm no existeix a request");
            return(SKIP_BODY);
        }
    }
    
    public void setNomLlista(String nomLlista) {
        this.nomLlista = nomLlista;
    }
    
    public void setCamps(String txCamps)
    {
        camps = new ArrayList<String>();
        StringTokenizer st = new StringTokenizer(txCamps, ",");
        while (st.hasMoreElements()){
            camps.add(st.nextToken());
        }    
    }
    
    public void setCapçalera(String txCamps)
    {
        capçalera = new ArrayList<String>();
        StringTokenizer st = new StringTokenizer(txCamps, ",");
        while (st.hasMoreElements()){
            capçalera.add(st.nextToken());
        }    
    }
   
    
    @Override
    public int doEndTag() 
    {
        return(EVAL_PAGE);
    }
    
}
